@@ -115,6 +115,8 @@
 #define ATTR_stagein  "stagein"
 #define ATTR_stageout "stageout"
 #define ATTR_jobtype  "jobtype"
+#define ATTR_submit_host "submit_host"
+#define ATTR_init_work_dir "init_work_dir"
 
 /* additional job and general attribute names */
 
@@ -461,7 +463,7 @@
 
 #define NO_MOM_RELAY 1
 
-enum batch_op { SET, UNSET, INCR, DECR, EQ, NE, GE, GT, LE, LT, DFLT, MERGE };
+enum batch_op { SET, UNSET, INCR, DECR, EQ, NE, GE, GT, LE, LT, DFLT, MERGE, INCR_OLD };
 
 /*
 ** This structure is identical to attropl so they can be used
