@@ -329,6 +329,8 @@ enum job_atr
   JOB_ATR_jobtype,     /* opaque job type string */
   JOB_ATR_inter_cmd,      /* command for interactive job */
   JOB_ATR_proxy_user,
+  JOB_ATR_submit_host,  /* host which submitted the job */
+  JOB_ATR_init_work_dir,    /* initial working directory */
 #ifdef USEJOBCREATE
   JOB_ATR_pagg_id,
 #endif /* USEJOBCREATE */
