@@ -78,7 +78,7 @@
 */
 
 /*
- * @(#) $Id: server_limits.h 3138 2009-09-29 21:43:58Z knielson $
+ * @(#) $Id: server_limits.h 4139 2010-10-06 20:43:44Z knielson $
  */
 
 /*
@@ -134,6 +134,9 @@
 #define NODE_DESCRIP  "nodes"
 #define NODE_STATUS  "node_status"
 #define NODE_NOTE  "node_note"
+#define PBS_CREDENTIALDIR "credentials"
+#define PBS_JOBINFOLOGDIR   "job_logs"
+
 
 #ifndef PBS_NET_MAX_CONNECTIONS
 /* 
