@@ -486,6 +486,7 @@ job_alloc(void)
   pj->ji_globid = NULL;
   pj->ji_stdout = 0;
   pj->ji_stderr = 0;
+  pj->ji_qs.ji_un.ji_momt.ji_exitstat = 0;
 
   pj->ji_momhandle = -1;  /* mark mom connection invalid */
 
@@ -697,6 +698,14 @@ void job_purge(
     unlink(file);
 
     pjob->ji_flags &= ~MOM_HAS_NODEFILE;
+
+    /* delete the gpufile if still hanging around */
+
+    sprintf(file, "%s/%sgpu",
+      path_aux,
+      pjob->ji_qs.ji_jobid);
+
+    unlink(file);
     }
 
   delete_link(&pjob->ji_jobque);
