@@ -109,7 +109,6 @@ extern int  exiting_tasks;
 extern char  mom_host[];
 extern tlist_head svr_alljobs;
 extern int  termin_child;
-extern int  killdelay;
 
 extern int       LOGLEVEL;
 
@@ -166,7 +165,7 @@ int set_job(
       AllocParCmd = strdup("/opt/moab/default/tools/partition.create.xt4.pl");
 
 #ifdef USEJOBCREATE
-#ifndef FORCESID
+
     if ((pjob->ji_wattr[(int)JOB_ATR_pagg_id].at_flags & ATR_VFLAG_SET) &&
       (pjob->ji_wattr[(int)JOB_ATR_pagg_id].at_val.at_ll != (long)JOB_FAIL) &&
       (pjob->ji_wattr[(int)JOB_ATR_pagg_id].at_val.at_ll > 0x00000000ffffffff))
@@ -178,7 +177,6 @@ int set_job(
                pjob->ji_wattr[(int)JOB_ATR_pagg_id].at_val.at_ll);
       }
     else
-#endif  /* FORCESID */
 #endif  /* USEJOBCREATE */
       {
       snprintf(tmpLine, sizeof(tmpLine), "%s --confirm -p %s -j %s -a %ld",
@@ -330,6 +328,9 @@ void scan_for_terminated(void)
   job *pjob;
   task *ptask = NULL;
   int  statloc;
+#ifdef USESAVEDRESOURCES
+  int update_stats = TRUE;
+#endif /* USESAVEDRESOURCES */
 
   int    tcount;
 
@@ -353,8 +354,49 @@ void scan_for_terminated(void)
 
     while (pjob != NULL)
       {
+
+#ifdef USESAVEDRESOURCES
+      ptask = (task *)GET_NEXT(pjob->ji_tasks);
+
+      /*
+       ** check task with associated process id to see if we are recovering
+       ** after a mom restart where process completed while we were gone
+        */
+      
+      while (ptask != NULL)
+        {
+        if (ptask->ti_flags & TI_FLAGS_RECOVERY)
+          {
+          if (LOGLEVEL >= 7)
+            {
+            snprintf(log_buffer, 1024, "found match for recovering job task for sid=%d",
+              ptask->ti_qs.ti_sid);
+
+            LOG_EVENT(
+              PBSEVENT_DEBUG,
+              PBS_EVENTCLASS_JOB,
+              pjob->ji_qs.ji_jobid,
+              log_buffer);
+            }
+          
+          update_stats = FALSE;
+          break;
+          }
+
+        ptask = (task *)GET_NEXT(ptask->ti_jobtask);
+        
+        }  /* END while (ptask) */
+      
+      if (update_stats)
+        {
+        mom_set_use(pjob);
+        }
+#else
+
       mom_set_use(pjob);
 
+#endif /* USESAVEDRESOURCES */
+
       pjob = (job *)GET_PRIOR(pjob->ji_alljobs);
       }
     }
@@ -528,8 +570,7 @@ void scan_for_terminated(void)
 
     /* where is job purged?  How do we keep job from progressing in state until the obit is sent? */
 
-    if (killdelay == 0)
-      kill_task(ptask, SIGKILL, 0);
+    kill_task(ptask, SIGKILL, 0);
 
     ptask->ti_qs.ti_exitstat = exiteval;
 
