@@ -120,9 +120,9 @@ static int   run_exit;
 
 /* external prototypes */
 
-extern int pe_input A_((char *));
-extern int TTmpDirName A_((job *, char *));
-extern void encode_used A_((job *, tlist_head *));
+extern int pe_input(char *);
+extern int TTmpDirName(job *, char *);
+extern void encode_used(job *, tlist_head *);
 #ifdef ENABLE_CSA
 extern void add_wkm_end(uint64_t, int64_t, char *);
 
@@ -413,7 +413,7 @@ int run_pelog(
           (pelog != NULL) ? pelog : "NULL",
           (pjob != NULL) ? pjob->ji_qs.ji_jobid : "NULL",
           getcwd(tmpBuf, sizeof(tmpBuf)),
-          (int)getpid());
+          getpid());
 
         log_record(PBSEVENT_SYSTEM, 0, id, log_buffer);
         }
