@@ -112,11 +112,11 @@
 
 /* External Functions Called: */
 
-extern int  reply_jid A_((char *));
-extern void start_exec A_((job *));
-extern int  svr_authorize_jobreq A_((struct batch_request *, job *));
-extern int  svr_chkque A_((job *, pbs_queue *, char *, int, char *));
-extern int  job_route A_((job *));
+extern int  reply_jid(char *);
+extern void start_exec(job *);
+extern int  svr_authorize_jobreq(struct batch_request *, job *);
+extern int  svr_chkque(job *, pbs_queue *, char *, int, char *);
+extern int  job_route(job *);
 extern void check_state(int);
 extern void mom_server_all_update_stat();
 
@@ -160,12 +160,12 @@ extern int decode_arst_merge(struct attribute *,char *,char *,char *);
 
 /* Private Functions in this file */
 
-static job *locate_new_job A_((int, char *));
+static job *locate_new_job(int, char *);
 
 #ifdef PNOT
-static int user_account_verify A_((char *, char *));
-static char *user_account_default A_((char *));
-static int user_account_read_user A_((char *));
+static int user_account_verify(char *, char *);
+static char *user_account_default(char *);
+static int user_account_read_user(char *);
 #endif /* PNOT */
 
 
@@ -736,28 +736,16 @@ void req_mvjobfile(
     return;
     }
 
-  if ((pwd = getpwnam(pj->ji_wattr[(int)JOB_ATR_euser].at_val.at_str)) == NULL)
+  if (((pwd = getpwnam(pj->ji_wattr[(int)JOB_ATR_euser].at_val.at_str)) == NULL) ||
+      ((fds = open_std_file(pj, jft, oflag, pwd->pw_gid)) < 0))
     {
     /* FAILURE */
+
     req_reject(PBSE_MOMREJECT, 0, preq, NULL, "password lookup failed");
 
     return;
     }
 
-  if ((fds = open_std_file(pj, jft, oflag, pwd->pw_gid)) < 0)
-    {
-    int keeping = 1;
-    char *path = std_file_name(pj, jft, &keeping);
-    
-    snprintf(log_buffer,sizeof(log_buffer),
-      "Cannot create file %s",
-      path);
-
-    req_reject(PBSE_SYSTEM, 0, preq, NULL, log_buffer);
-
-    return;
-    }
-
   if (write(
         fds,
         preq->rq_ind.rq_jobfile.rq_data,
