@@ -99,8 +99,6 @@
 #include <sys/systeminfo.h>
 #include <sys/time.h>
 #include <sys/types.h>
-#include <sys/ctype.h>
-#include <signal.h>
 #include <sys/procfs.h>
 #include <sys/proc.h>
 #include <sys/resource.h>
@@ -138,7 +136,7 @@
 **  loadave  current load average
 */
 
-static char ident[] = "@(#) solaris5/$RCSfile$ $Revision: 3393 $";
+static char ident[] = "@(#) solaris5/$RCSfile$ $Revision: 3230 $";
 
 #ifndef TRUE
 #define FALSE 0
@@ -153,9 +151,9 @@ static char ident[] = "@(#) solaris5/$RCSfile$ $Revision: 3393 $";
 ** external functions and data
 */
 
-extern struct config  *search A_((struct config *, char *));
+extern struct config  *search(struct config *, char *);
 
-extern struct rm_attribute *momgetattr A_((char *));
+extern struct rm_attribute *momgetattr(char *);
 extern int   rm_errno;
 extern unsigned int reqnum;
 extern double cputfactor;
@@ -169,13 +167,13 @@ extern  int     ignmem;
 /*
 ** local functions and data
 */
-static char *resi  A_((struct rm_attribute *attrib));
-static char *physmem A_((struct rm_attribute *attrib));
-static char *ncpus  A_((struct rm_attribute *attrib));
-static char *walltime A_((struct rm_attribute *attrib));
-static char *platform A_((struct rm_attribute *attrib));
-extern char *nullproc A_((struct rm_attribute *attrib));
-extern char     *loadave A_((struct rm_attribute *attrib));
+static char *resi(struct rm_attribute *attrib);
+static char *physmem(struct rm_attribute *attrib);
+static char *ncpus(struct rm_attribute *attrib);
+static char *walltime(struct rm_attribute *attrib);
+static char *platform(struct rm_attribute *attrib);
+extern char *nullproc(struct rm_attribute *attrib);
+extern char *loadave(struct rm_attribute *attrib);
 
 char  procfs[] = "/proc";
 char  procfmts[] = "/proc/%s";
@@ -371,8 +369,8 @@ cput_sum(job *pjob)
     if (pi->pr_state == SZOMB)
       {
       cputime += tv(pi->pr_time);
-      DBPRT(("%s: ses %d pid %d (zombie) cputime %ld\n",
-             id, (int)pi->pr_sid, (int)pi->pr_pid, cputime))
+      DBPRT(("%s: ses %d pid %d (zombie) cputime %d\n",
+             id, pi->pr_sid, pi->pr_pid, cputime))
       continue;
       }
 
@@ -382,8 +380,8 @@ cput_sum(job *pjob)
               tv(ps->pr_cutime) + tv(ps->pr_cstime);
 
     cputime += addtime;
-    DBPRT(("%s: ses %d pid %d cputime %ld\n",
-           id, (int)pi->pr_sid, (int)ps->pr_pid, cputime))
+    DBPRT(("%s: ses %d pid %d cputime %d\n",
+           id, pi->pr_sid, ps->pr_pid, cputime))
     }
 
   if (nps == 0)
@@ -401,6 +399,7 @@ cput_sum(job *pjob)
 static int
 overcput_proc(job *pjob, unsigned long limit)
   {
+  char  *id = "overcput_proc";
   ulong  memsize;
   ulong  cputime;
   int  i;
@@ -435,6 +434,7 @@ overcput_proc(job *pjob, unsigned long limit)
 static unsigned long
 mem_sum(job *pjob)
   {
+  char  *id = "mem_sum";
   ulong  memsize;
   int  i;
   prpsinfo_t *pi;
@@ -460,6 +460,7 @@ mem_sum(job *pjob)
 static unsigned long
 resi_sum(job *pjob)
   {
+  char  *id = "resi_sum";
   ulong  resisize;
   int  i;
   prpsinfo_t *pi;
@@ -492,8 +493,6 @@ error(char *string, int value)
   assert(string != NULL);
   assert(*string != '\0');
 
-  message = ident; /* this is here to only make the compiler not give a warning
-                      for an unused variable ident */
   message = pbse_to_txt(value);
 
   assert(message != NULL);
@@ -941,7 +940,7 @@ mom_over_limit(job *pjob)
       if (num > value)
         {
         sprintf(log_buffer,
-                "walltime %ld exceeded limit %ld",
+                "walltime %d exceeded limit %d",
                 num, value);
         return (TRUE);
         }
@@ -963,6 +962,7 @@ mom_over_limit(job *pjob)
 int
 mom_set_use(job *pjob)
   {
+  char   *id = "mom_set_use";
   resource  *pres;
   attribute  *at;
   resource_def  *rd;
@@ -1048,6 +1048,7 @@ mom_set_use(job *pjob)
 int
 kill_task(task *ptask, int sig, int pg)
   {
+  char  *id = "kill_task";
   int  ct = 0;
   prpsinfo_t *pi;
   int  i, sesid;
@@ -1144,6 +1145,7 @@ int
 getprocs(void)
   {
   static unsigned int lastproc = 0;
+  static char  id[] = "getprocs";
 
   if (lastproc == reqnum)  /* don't need new proc table */
     return 1;
@@ -1160,7 +1162,7 @@ double
 dsecs(t)
 timestruc_t     *t;
   {
-  DBPRT(("\tsecs: %d\tnsecs: %ld\n", (int)t->tv_sec, t->tv_nsec))
+  DBPRT(("\tsecs: %d\tnsecs: %d\n", t->tv_sec, t->tv_nsec))
   return ((double)t->tv_sec + ((double)t->tv_nsec * 1.0e-9));
   }
 
@@ -1199,7 +1201,7 @@ pid_t jobid;
     cputime += addtime;
 
     DBPRT(("%s: total %.2f pid %d %.2f\n", id, cputime,
-           (int)ps->pr_pid, addtime))
+           ps->pr_pid, addtime))
 
     }
 
@@ -1218,9 +1220,10 @@ char *
 cput_proc(pid)
 pid_t pid;
   {
+  char   *id = "cput_pid";
   double   cputime;
   int   i;
-  prstatus_t  *ps = NULL;
+  prstatus_t  *ps;
 
   if (getprocs() == 0)
     {
@@ -1321,13 +1324,13 @@ pid_t jobid;
 
     memsize += pi->pr_size;
 
-    DBPRT(("%s: total %ld pid %d %ld\n", id, memsize*page_size,
-           (int)pi->pr_pid, pi->pr_size*page_size))
+    DBPRT(("%s: total %d pid %d %d\n", id, memsize*page_size,
+           pi->pr_pid, pi->pr_size*page_size))
     }
 
   if (found)
     {
-    sprintf(ret_string, "%ldkb", (memsize*page_size) >> 10); /* KB */
+    sprintf(ret_string, "%ukb", (memsize*page_size) >> 10); /* KB */
     return ret_string;
     }
 
@@ -1340,7 +1343,8 @@ char *
 mem_proc(pid)
 pid_t pid;
   {
-  prpsinfo_t  *pi = NULL;
+  char   *id = "mem_proc";
+  prpsinfo_t  *pi;
   int   i;
 
   if (getprocs() == 0)
@@ -1363,7 +1367,7 @@ pid_t pid;
     return NULL;
     }
 
-  sprintf(ret_string, "%ldkb", (pi->pr_size * page_size) >> 10); /* KB */
+  sprintf(ret_string, "%ukb", (pi->pr_size * page_size) >> 10); /* KB */
 
   return ret_string;
   }
@@ -1411,6 +1415,7 @@ static char *
 resi_job(jobid)
 pid_t jobid;
   {
+  char   *id = "resi_job";
   int   resisize;
   int   i;
   int   found = 0;
@@ -1438,7 +1443,7 @@ pid_t jobid;
 
   if (found)
     {
-    sprintf(ret_string, "%ldkb", (resisize*page_size) >> 10); /* KB */
+    sprintf(ret_string, "%ukb", (resisize*page_size) >> 10); /* KB */
     return ret_string;
     }
 
@@ -1451,7 +1456,8 @@ static char *
 resi_proc(pid)
 pid_t pid;
   {
-  prpsinfo_t  *pi = NULL;
+  char   *id = "resi_proc";
+  prpsinfo_t  *pi;
   int   i;
 
   if (getprocs() == 0)
@@ -1474,7 +1480,7 @@ pid_t pid;
     return NULL;
     }
 
-  sprintf(ret_string, "%ldkb", (pi->pr_rssize * page_size) >> 10); /* KB */
+  sprintf(ret_string, "%ukb", (pi->pr_rssize * page_size) >> 10); /* KB */
 
   return ret_string;
   }
@@ -1482,7 +1488,7 @@ pid_t pid;
 static char *
 resi(struct rm_attribute *attrib)
   {
-  char  *id = "resi";
+  char   *id = "resi";
   int   value;
 
   if (attrib == NULL)
@@ -1521,7 +1527,7 @@ resi(struct rm_attribute *attrib)
 char *
 sessions(struct rm_attribute *attrib)
   {
-  char *id = "sessions";
+  char   *id = "sessions";
   int   i, j;
   prpsinfo_t  *pi;
   char   *fmt;
@@ -1564,7 +1570,7 @@ sessions(struct rm_attribute *attrib)
       continue;
 
     DBPRT(("%s[%d]: pid %d sid %d\n",
-           id, (int)njids, (int)pi->pr_pid, (int)jobid))
+           id, njids, pi->pr_pid, jobid))
 
     for (j = 0; j < njids; j++)
       {
@@ -1638,7 +1644,7 @@ pids(struct rm_attribute *attrib)
   {
   char  *id = "pids";
   pid_t  jobid;
-  int  i;
+  int  i, j;
   prpsinfo_t *pi;
   char  *fmt;
   int  num_pids;
@@ -1689,12 +1695,12 @@ pids(struct rm_attribute *attrib)
     pi = &proc_info[i];
 
     DBPRT(("%s[%d]: pid: %d sid %d\n",
-           id, num_pids, (int)pi->pr_pid, (int)pi->pr_sid))
+           id, num_pids, pi->pr_pid, pi->pr_sid))
 
     if (jobid != pi->pr_sid)
       continue;
 
-    sprintf(fmt, "%d ", (int)pi->pr_pid);
+    sprintf(fmt, "%d ", pi->pr_pid);
 
     fmt += strlen(fmt);
 
@@ -1749,7 +1755,7 @@ nusers(struct rm_attribute *attrib)
       continue;
 
     DBPRT(("%s[%d]: pid %d uid %d\n",
-           id, nuids, (int)pi->pr_pid, uid))
+           id, nuids, pi->pr_pid, uid))
 
     for (j = 0; j < nuids; j++)
       {
@@ -1797,7 +1803,7 @@ ncpus(struct rm_attribute *attrib)
     return NULL;
     }
 
-  sprintf(ret_string, "%ld", sysconf(_SC_NPROCESSORS_ONLN));
+  sprintf(ret_string, "%d", sysconf(_SC_NPROCESSORS_ONLN));
 
   system_ncpus = sysconf(_SC_NPROCESSORS_ONLN);
   return ret_string;
@@ -1826,7 +1832,9 @@ char *
 size_fs(char *param)
   {
   char  *id = "size_fs";
+  FILE  *mf;
 
+  struct mntent *mp;
 
   struct statvfs fsbuf;
 
@@ -1875,7 +1883,7 @@ size_file(char *param)
     return NULL;
     }
 
-  sprintf(ret_string, "%ldkb", sbuf.st_size >> 10); /* KB */
+  sprintf(ret_string, "%ukb", sbuf.st_size >> 10); /* KB */
 
   return ret_string;
   }
@@ -2070,25 +2078,20 @@ walltime(struct rm_attribute *attrib)
   return NULL;
   }
 
-
 int
 get_la(double *rv)
   {
   char *id = "get_la";
   kvm_t *kd;
   long load;
-  char *avenrun = "avenrun";
 
-  static struct nlist nl[2];
+  static struct nlist nl[] =
+    {
+      { "avenrun"
+      },
 
-  nl[0].n_name = avenrun;
-  nl[0].n_value = 0;
-  nl[0].n_scnum = 0;
-  nl[0].n_type = 0;
-  nl[0].n_sclass = NULL;
-  nl[0].n_numaux = NULL;
-
-  nl[1].n_name = NULL;
+    { "" }
+    };
 
   kd = kvm_open(NULL, NULL, NULL, O_RDONLY, NULL);
 
@@ -2164,5 +2167,3 @@ void scan_non_child_tasks(void)
   }  /* END scan_non_child_tasks() */
 
 
-
-
