@@ -108,7 +108,6 @@
 
 /* Global Data Items: */
 
-extern char *server_name;
 extern struct connect_handle connection[];
 extern char     *msg_daemonname;
 extern tlist_head task_list_event;
@@ -125,7 +124,7 @@ extern struct pbsnode *tfind_addr(const u_long);
 
 extern int       LOGLEVEL;
 
-int issue_to_svr A_((char *, struct batch_request *, void (*f)(struct work_task *)));
+int issue_to_svr(char *, struct batch_request *, void (*f)(struct work_task *));
 
 /*
  * relay_to_mom - relay a (typically existing) batch_request to MOM
@@ -143,7 +142,7 @@ int relay_to_mom(
 
   pbs_net_t          momaddr, /* address of mom */
   struct batch_request  *request, /* the request to send */
-  void (*func) A_((struct work_task *)))
+  void (*func)(struct work_task *))
 
   {
   char *id = "relay_to_mom";
@@ -249,7 +248,7 @@ int issue_to_svr(
 
   char                 *servern,                  /* I */
   struct batch_request *preq,                     /* I */
-  void (*replyfunc)     A_((struct work_task *))) /* I */
+  void (*replyfunc)    (struct work_task *))      /* I */
 
   {
   int   do_retry = 0;
@@ -265,7 +264,7 @@ int issue_to_svr(
   preq->rq_fromsvr = 1;
   preq->rq_perm = ATR_DFLAG_MGRD | ATR_DFLAG_MGWR | ATR_DFLAG_SvWR;
 
-  svrname = parse_servername(servern, &port); 
+  svrname = parse_servername(servern, &port);
   svraddr = get_hostaddr(svrname);
 
   if (svraddr == (pbs_net_t)0)
@@ -375,7 +374,7 @@ int issue_Drequest(
 
   int          conn,
   struct batch_request *request,
-  void (*func) A_((struct work_task *)),
+  void (*func) (struct work_task *),
   struct work_task    **ppwt)
 
   {
