@@ -1153,6 +1153,19 @@ attribute_def svr_attr_def[] = {
    PARENT_TYPE_SERVER},
 #endif
 
+  /* SRV_ATR_MoabArrayCompatible */
+  {ATTR_moabarraycompatible,
+   decode_b,
+   encode_b,
+   set_b,
+   comp_b,
+   free_null,
+   NULL_FUNC,
+   NO_USER_SET,
+   ATR_TYPE_LONG,
+   PARENT_TYPE_SERVER
+  },
+
   /* site supplied server attribute definitions if any, see site_svr_attr_*.h  */
 #include "site_svr_attr_def.h"
 
